<?php
/**
 * VW Blog Magazine Theme Customizer
 *
 * @package VW Blog Magazine
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function vw_blog_magazine_custom_controls() {

    load_template( trailingslashit( get_template_directory() ) . '/inc/custom-controls.php' );
}
add_action( 'customize_register', 'vw_blog_magazine_custom_controls' );

function vw_blog_magazine_customize_register( $wp_customize ) {

	load_template( trailingslashit( get_template_directory() ) . 'inc/customize-homepage/class-customize-homepage.php' );

	//add home page setting pannel
	$wp_customize->add_panel( 'vw_blog_magazine_panel_id', array(
	    'priority' => 10,
	    'capability' => 'edit_theme_options',
	    'theme_supports' => '',
	    'title' => __( 'VW Settings', 'vw-blog-magazine' ),
	    'description' => __( 'Description of what this panel does.', 'vw-blog-magazine' ),
	) );

	$wp_customize->add_section( 'vw_blog_magazine_left_right', array(
    	'title'      => __( 'General Settings', 'vw-blog-magazine' ),
		'priority'   => 30,
		'panel' => 'vw_blog_magazine_panel_id'
	) );

	$wp_customize->add_setting('vw_blog_magazine_width_option',array(
        'default' => __('Full Width','vw-blog-magazine'),
        'sanitize_callback' => 'vw_blog_magazine_sanitize_choices'
	));
	$wp_customize->add_control(new VW_Blog_Magazine_Image_Radio_Control($wp_customize, 'vw_blog_magazine_width_option', array(
        'type' => 'select',
        'label' => __('Width Layouts','vw-blog-magazine'),
        'description' => __('Here you can change the width layout of Website.','vw-blog-magazine'),
        'section' => 'vw_blog_magazine_left_right',
        'choices' => array(
            'Full Width' => get_template_directory_uri().'/images/full-width.png',
            'Wide Width' => get_template_directory_uri().'/images/wide-width.png',
            'Boxed' => get_template_directory_uri().'/images/boxed-width.png',
    ))));

	// Add Settings and Controls for Layout
	$wp_customize->add_setting('vw_blog_magazine_theme_options',array(
        'default' => __('Right Sidebar','vw-blog-magazine'),
        'sanitize_callback' => 'vw_blog_magazine_sanitize_choices'	        
	));
	$wp_customize->add_control('vw_blog_magazine_theme_options', array(
        'type' => 'select',
        'label' => __('Post Sidebar Layout','vw-blog-magazine'),
        'description' => __('Here you can change the sidebar layout for posts. ','vw-blog-magazine'),
        'section' => 'vw_blog_magazine_left_right',
        'choices' => array(
            'Left Sidebar' => __('Left Sidebar','vw-blog-magazine'),
            'Right Sidebar' => __('Right Sidebar','vw-blog-magazine'),
            'One Column' => __('One Column','vw-blog-magazine'),
            'Three Columns' => __('Three Columns','vw-blog-magazine'),
            'Four Columns' => __('Four Columns','vw-blog-magazine'),
            'Grid Layout' => __('Grid Layout','vw-blog-magazine')
        ),
	));

	$wp_customize->add_setting('vw_blog_magazine_page_layout',array(
        'default' => __('One Column','vw-blog-magazine'),
        'sanitize_callback' => 'vw_blog_magazine_sanitize_choices'
	));
	$wp_customize->add_control('vw_blog_magazine_page_layout',array(
        'type' => 'select',
        'label' => __('Page Sidebar Layout','vw-blog-magazine'),
        'description' => __('Here you can change the sidebar layout for pages. ','vw-blog-magazine'),
        'section' => 'vw_blog_magazine_left_right',
        'choices' => array(
            'Left Sidebar' => __('Left Sidebar','vw-blog-magazine'),
            'Right Sidebar' => __('Right Sidebar','vw-blog-magazine'),
            'One Column' => __('One Column','vw-blog-magazine')
        ),
	) );

	//Our Blog Category section
  	$wp_customize->add_section('vw_blog_magazine_category_section',array(
	    'title' => __('Category Section','vw-blog-magazine'),
	    'description' => '',
	    'priority'  => null,
	    'panel' => 'vw_blog_magazine_panel_id',
	)); 

	$categories = get_categories();
	$cats = array();
	$i = 0;
	$cat_pst[]= 'select';
	foreach($categories as $category){
		if($i==0){
			$default = $category->slug;
			$i++;
		}
		$cat_pst[$category->slug] = $category->name;
	}

	$wp_customize->add_setting('vw_blog_magazine_category',array(
	    'default' => 'select',
	    'sanitize_callback' => 'vw_blog_magazine_sanitize_choices',
  	));

  	$wp_customize->add_control('vw_blog_magazine_category',array(
	    'type'    => 'select',
	    'choices' => $cat_pst,
	    'label' => __('Select Category to display Latest Post','vw-blog-magazine'),
	    'section' => 'vw_blog_magazine_category_section',
	));

	//Category section 2
  	$wp_customize->add_section('vw_blog_magazine_cat_two_sec',array(
	    'title' => __('Category section 2','vw-blog-magazine'),
	    'description' => '',
	    'priority'  => null,
	    'panel' => 'vw_blog_magazine_panel_id',
	)); 

	$categories = get_categories();
	$cats = array();
	$i = 0;
	$cat_pst1[]= 'select';
	foreach($categories as $category){
		if($i==0){
			$default = $category->slug;
			$i++;
		}
		$cat_pst1[$category->slug] = $category->name;
	}

	$wp_customize->add_setting('vw_blog_magazine_section_two',array(
	    'default' => 'select',
	    'sanitize_callback' => 'vw_blog_magazine_sanitize_choices',
  	));

  	$wp_customize->add_control('vw_blog_magazine_section_two',array(
	    'type'    => 'select',
	    'choices' => $cat_pst1,
	    'label' => __('Select Category to display Latest Post','vw-blog-magazine'),
	    'section' => 'vw_blog_magazine_cat_two_sec',
	));

	//Category 2 excerpt
	$wp_customize->add_setting( 'vw_blog_magazine_category_excerpt_number', array(
		'default'              => 30,
		'type'                 => 'theme_mod',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'absint',
		'sanitize_js_callback' => 'absint',
	));
	$wp_customize->add_control( 'vw_blog_magazine_category_excerpt_number', array(
		'label'       => esc_html__( 'Category Excerpt length','vw-blog-magazine' ),
		'section'     => 'vw_blog_magazine_cat_two_sec',
		'type'        => 'range',
		'settings'    => 'vw_blog_magazine_category_excerpt_number',
		'input_attrs' => array(
			'step'             => 5,
			'min'              => 0,
			'max'              => 50,
		),
	));

	//Blog Post
	$wp_customize->add_section('vw_blog_magazine_blog_post',array(
		'title'	=> __('Blog Post Settings','vw-blog-magazine'),
		'panel' => 'vw_blog_magazine_panel_id',
	));	

	$wp_customize->add_setting( 'vw_blog_magazine_toggle_postdate',array(
        'default' => 1,
        'transport' => 'refresh',
        'sanitize_callback' => 'vw_blog_magazine_switch_sanitization'
    ));
    $wp_customize->add_control( new VW_Blog_Magazine_Toggle_Switch_Custom_Control( $wp_customize, 'vw_blog_magazine_toggle_postdate',array(
        'label' => esc_html__( 'Post Date','vw-blog-magazine' ),
        'section' => 'vw_blog_magazine_blog_post'
    )));

    $wp_customize->add_setting( 'vw_blog_magazine_toggle_author',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'vw_blog_magazine_switch_sanitization'
    ));
    $wp_customize->add_control( new VW_Blog_Magazine_Toggle_Switch_Custom_Control( $wp_customize, 'vw_blog_magazine_toggle_author',array(
		'label' => esc_html__( 'Author','vw-blog-magazine' ),
		'section' => 'vw_blog_magazine_blog_post'
    )));

    $wp_customize->add_setting( 'vw_blog_magazine_toggle_comments',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'vw_blog_magazine_switch_sanitization'
    ));
    $wp_customize->add_control( new VW_Blog_Magazine_Toggle_Switch_Custom_Control( $wp_customize, 'vw_blog_magazine_toggle_comments',array(
		'label' => esc_html__( 'Comments','vw-blog-magazine' ),
		'section' => 'vw_blog_magazine_blog_post'
    )));

    $wp_customize->add_setting( 'vw_blog_magazine_excerpt_number', array(
		'default'              => 30,
		'type'                 => 'theme_mod',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'absint',
		'sanitize_js_callback' => 'absint',
	));
	$wp_customize->add_control( 'vw_blog_magazine_excerpt_number', array(
		'label'       => esc_html__( 'Excerpt length','vw-blog-magazine' ),
		'section'     => 'vw_blog_magazine_blog_post',
		'type'        => 'range',
		'settings'    => 'vw_blog_magazine_excerpt_number',
		'input_attrs' => array(
			'step'             => 5,
			'min'              => 0,
			'max'              => 50,
		),
	));

	//Content Creation
	$wp_customize->add_section( 'vw_blog_magazine_content_section' , array(
    	'title' => __( 'Customize Home Page Settings', 'vw-blog-magazine' ),
		'priority' => null,
		'panel' => 'vw_blog_magazine_panel_id'
	));

	$wp_customize->add_setting('vw_blog_magazine_content_creation_main_control', array(
		'sanitize_callback' => 'esc_html',
	));

	$homepage= get_option( 'page_on_front' );

	$wp_customize->add_control(	new VW_Blog_Magazine_Content_Creation( $wp_customize, 'vw_blog_magazine_content_creation_main_control', array(
		'options' => array(
			esc_html__( 'First select static page in homepage setting for front page.Below given edit button is to customize Home Page. Just click on the edit option, add whatever elements you want to include in the homepage, save the changes and you are good to go.','vw-blog-magazine' ),
		),
		'section' => 'vw_blog_magazine_content_section',
		'button_url'  => admin_url( 'post.php?post='.$homepage.'&action=edit'),
		'button_text' => esc_html__( 'Edit', 'vw-blog-magazine' ),
	)));

	//footer
	$wp_customize->add_section('vw_blog_magazine_footer_section',array(
		'title'	=> __('Footer Text','vw-blog-magazine'),
		'description'	=> __('Add some text for footer like copyright etc.','vw-blog-magazine'),
		'priority'	=> null,
		'panel' => 'vw_blog_magazine_panel_id',
	));
	
	$wp_customize->add_setting('vw_blog_magazine_footer_copy',array(
		'default'	=> '',
		'sanitize_callback'	=> 'sanitize_text_field',
	));
	$wp_customize->add_control('vw_blog_magazine_footer_copy',array(
		'label'	=> __('Copyright Text','vw-blog-magazine'),
		'section'	=> 'vw_blog_magazine_footer_section',
		'type'		=> 'text'
	));

	$wp_customize->add_setting( 'vw_blog_magazine_hide_show_scroll',array(
    	'default' => 1,
      	'transport' => 'refresh',
      	'sanitize_callback' => 'vw_blog_magazine_switch_sanitization'
    ));  
    $wp_customize->add_control( new VW_Blog_Magazine_Toggle_Switch_Custom_Control( $wp_customize, 'vw_blog_magazine_hide_show_scroll',array(
      	'label' => esc_html__( 'Show / Hide Scroll To Top','vw-blog-magazine' ),
      	'section' => 'vw_blog_magazine_footer_section'
    )));

	$wp_customize->add_setting('vw_blog_magazine_scroll_top_alignment',array(
        'default' => __('Right','vw-blog-magazine'),
        'sanitize_callback' => 'vw_blog_magazine_sanitize_choices'
	));
	$wp_customize->add_control(new VW_Blog_Magazine_Image_Radio_Control($wp_customize, 'vw_blog_magazine_scroll_top_alignment', array(
        'type' => 'select',
        'label' => __('Scroll To Top','vw-blog-magazine'),
        'section' => 'vw_blog_magazine_footer_section',
        'settings' => 'vw_blog_magazine_scroll_top_alignment',
        'choices' => array(
            'Left' => get_template_directory_uri().'/images/layout1.png',
            'Center' => get_template_directory_uri().'/images/layout2.png',
            'Right' => get_template_directory_uri().'/images/layout3.png'
    ))));
	/** home page setions end here**/	
}
add_action( 'customize_register', 'vw_blog_magazine_customize_register' );

load_template( trailingslashit( get_template_directory() ) . '/inc/logo-resizer.php' );

/**
 * Singleton class for handling the theme's customizer integration.
 *
 * @since  1.0.0
 * @access public
 */
final class VW_Blog_Magazine_Customize {

	/**
	 * Returns the instance.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return object
	 */
	public static function get_instance() {

		static $instance = null;

		if ( is_null( $instance ) ) {
			$instance = new self;
			$instance->setup_actions();
		}

		return $instance;
	}

	/**
	 * Constructor method.
	 *
	 * @since  1.0.0
	 * @access private
	 * @return void
	 */
	private function __construct() {}

	/**
	 * Sets up initial actions.
	 *
	 * @since  1.0.0
	 * @access private
	 * @return void
	 */
	private function setup_actions() {

		// Register panels, sections, settings, controls, and partials.
		add_action( 'customize_register', array( $this, 'sections' ) );

		// Register scripts and styles for the controls.
		add_action( 'customize_controls_enqueue_scripts', array( $this, 'enqueue_control_scripts' ), 0 );
	}

	/**
	 * Sets up the customizer sections.
	 *
	 * @since  1.0.0
	 * @access public
	 * @param  object  $manager
	 * @return void
	 */
	public function sections( $manager ) {

		// Load custom sections.
		load_template( trailingslashit( get_template_directory() ) . '/inc/section-pro.php' );

		// Register custom section types.
		$manager->register_section_type( 'VW_Blog_Magazine_Customize_Section_Pro' );

		// Register sections.
		$manager->add_section(new VW_Blog_Magazine_Customize_Section_Pro($manager,'example_1',array(
			'priority'   => 1,
			'title'    => esc_html__( 'Premium Blog Theme', 'vw-blog-magazine' ),
			'pro_text' => esc_html__( 'Upgrade Pro',         'vw-blog-magazine' ),
			'pro_url'  => esc_url('https://www.vwthemes.com/themes/best-premium-wordpress-blog-theme/')
		)));

		// Register sections.
		$manager->add_section(new VW_Blog_Magazine_Customize_Section_Pro($manager,'example_2',array(
			'priority'   => 1,
			'title'    => esc_html__( 'Documentation', 'vw-blog-magazine' ),
			'pro_text' => esc_html__( 'Docs', 'vw-blog-magazine' ),
			'pro_url'  => esc_url( 'themes.php?page=vw_blog_magazine_guide' )
		)));
	}

	/**
	 * Loads theme customizer CSS.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return void
	 */
	public function enqueue_control_scripts() {

		wp_enqueue_script( 'vw-blog-magazine-customize-controls', trailingslashit( get_template_directory_uri() ) . '/js/customize-controls.js', array( 'customize-controls' ) );

		wp_enqueue_style( 'vw-blog-magazine-customize-controls', trailingslashit( get_template_directory_uri() ) . '/css/customize-controls.css' );
	}
}

// Doing this customizer thang!
VW_Blog_Magazine_Customize::get_instance();